//
// RegexReplace: Perform an operation not unlike Perl's s/this/that/ on
// strings. Uses the GNU re library. RE Syntax is Perl like.
//
// $Id: RegexReplace.h,v 1.0 2000/08/16 13:01:00 aarmstrong Exp $
//
// $Log: RegexReplace.h,v $
// Revision 1.0  2000/08/16 13:01:00  aarmstrong
// New files.
//
//
#ifndef __RegexReplace_h
#define __RegexReplace_h

#include "htString.h"
#include "regex.h"		// get the GNU regex stuff

class RegexReplace : public Object
{
public:
  // Construct a RegexReplace that will translate strings that match
  // the pattern in |from| with the replacement pattern in |to|. If pError
  // is supplied it will contain any error condition that occurs while
  // compiling the RE
  RegexReplace(const String &from, const String &to, String &error);
  virtual ~RegexReplace();
  virtual String Replace(const String &source);
  //virtual String ToString() const { return toString; }

private:
  RegexReplace(const RegexReplace &); // Not supposed to be implemented.
  void operator= (const RegexReplace &); // Not supposed to be implemented.

  // regex matching stuff

  struct re_pattern_buffer re;    // This is the compiled source regex
  struct re_registers regs;       // Match registers

  char *repBuf;      // Replace text.
  size_t segSize, segUsed;
  int *segMark;
  size_t repLen;

  //String toString;     // used mainly for debugging

  // Various private methods
  void Empty();   // Dispose of the contents
  void ParseReplaceSpec(const String &to);
  void PutMark(int n);
};

#endif /* __RegexReplace_h */
