//
// RegexReplaceList
//
// $Id: RegexReplaceList.cc,v 1.0 2000/08/16 14:18:00 aarmstrong Exp $
//
//

#include "RegexReplaceList.h"
#include <stream.h>

RegexReplaceList::RegexReplaceList(StringList &list, String &error)
{
	if (list.Count() & 1)
	{
		error = "RegexReplaceList needs an even number of strings";
		return;
	}

	int i;
	String err;

	for (i = 0; i < list.Count(); i += 2)
	{
		String from = list[i];
		String to	= list[i+1];
		RegexReplace *replacer = new RegexReplace(from, to, err);
		replacers.Add(replacer);		// Stash it even if there's an error so it will get destroyed later
		if (err.length() != 0)
		{
			error = err;
			return;
		}
	}
}

RegexReplaceList::~RegexReplaceList()
{
	// replacers gets chucked away
}

String RegexReplaceList::Replace(const String &source)
{
	// Very slight optimisation: if the replacer list is empty we
	// bail out immediately to save making a copy of the source
	// string.

	int repCount = replacers.Count();
	if (repCount == 0) return source;
	//cout << "*** " << replacers.Count() << " replacers" << endl;
	//cout << "*** replacing " << source.get() << endl;

	String result = source;
	for (int rep = 0; rep < repCount; rep++)
	{
		RegexReplace *replacer = (RegexReplace *) replacers[rep];
		result = replacer->Replace(result);
		//cout << "***       via " << replacer->ToString().get() << " (" << result.get() << ")" << endl;
	}

	//cout << "***      with " << result.get() << endl;

	return result;
}

// End of RegexReplaceList.cc
